@@ -1570,6 +1570,25 @@ gconf_engine_all_entries(GConfEngine* conf, const gchar* dir, GError** err)
   return pairs;
 }
 
+
+static void
+qualify_keys (GSList *keys, const char *dir)
+{
+  GSList *tmp = keys;
+  while (tmp != NULL)
+    {
+      char *key = tmp->data;
+      gchar *full;
+
+      full = gconf_concat_dir_and_key (dir, key);
+
+      g_free (tmp->data);
+      tmp->data = full;
+
+      tmp = g_slist_next (tmp);
+    }
+}
+
 GSList*      
 gconf_engine_all_dirs(GConfEngine* conf, const gchar* dir, GError** err)
 {
@@ -1612,7 +1631,7 @@ gconf_engine_all_dirs(GConfEngine* conf, const gchar* dir, GError** err)
           return NULL;
         }
 
-      qualify_entries (retval, dir);
+      qualify_keys (retval, dir);
       
       return retval;
     }
@@ -2537,7 +2556,7 @@ gconf_escape_key (const char *arbitrary_text,
   if (len < 0)
     len = strlen (arbitrary_text);
 
-  retval = g_string_new ("");
+  retval = g_string_new (NULL);
 
   p = arbitrary_text;
   end = arbitrary_text + len;
@@ -2583,7 +2602,7 @@ gconf_unescape_key (const char *escaped_key,
   if (len < 0)
     len = strlen (escaped_key);
 
-  retval = g_string_new ("");
+  retval = g_string_new (NULL);
 
   p = escaped_key;
   end = escaped_key + len;
@@ -3434,7 +3453,7 @@ gconf_handle_corba_exception(CORBA_Environment* ev, GError** err)
 
         if (err)
           *err = gconf_error_new (corba_errno_to_gconf_errno (ce->err_no),
-                                  ce->message);
+                                  "%s", ce->message);
         CORBA_exception_free (ev);
         return TRUE;
       }
